Struct trace_time::PerfTimer[][src]

pub struct PerfTimer { /* fields omitted */ }

Performance timer with logging. Starts measuring time in the constructor, prints elapsed time in the destructor or when stop is called.

Methods

impl PerfTimer
[src]

Create an instance with given name.